Vec2d

Struct Vec2d 

pub struct Vec2d<T> { /* private fields */ }

Implementations

Source

impl Vec2d<f32>

pub fn unit_vector(direction: f32) -> Self

Creates a new unit vector in a specific direction

pub fn normalise(self) -> Self

Normalises the vector

pub fn magnitude(&self) -> f32

Returns the magnitude/length of the vector

pub fn square_magnitude(&self) -> f32

Returns the (non-sqrt) magnitude/length of the vector

pub fn direction(&self) -> f32

Returns direction the vector is pointing

pub fn clear(&mut self)

Source

impl Vec2d<f64>

pub fn unit_vector(direction: f64) -> Self

Creates a new unit vector in a specific direction

pub fn normalise(self) -> Self

Normalises the vector

pub fn magnitude(&self) -> f64

Returns the magnitude/length of the vector

pub fn square_magnitude(&self) -> f64

Returns the (non-sqrt) magnitude/length of the vector

pub fn direction(&self) -> f64

Returns direction the vector is pointing

pub fn clear(&mut self)

Source

impl<T> Vec2d<T>

pub fn new(x: T, y: T) -> Vec2d<T>
where T: Add + Mul + Div + Sub + Copy,

pub fn x(&self) -> T
where T: Add + Mul + Div + Sub + Copy,

pub fn set_x(&mut self, x: T)
where T: Add + Mul + Div + Sub + Copy,

pub fn y(&self) -> T
where T: Add + Mul + Div + Sub + Copy,

pub fn set_y(&mut self, y: T)
where T: Add + Mul + Div + Sub + Copy,