pub struct Vec2d<T> { /* private fields */ }Implementations
Sourceimpl Vec2d<f32>
impl Vec2d<f32>
Sourcepub fn unit_vector(direction: f32) -> Self
pub fn unit_vector(direction: f32) -> Self
Creates a new unit vector in a specific direction
Sourcepub fn square_magnitude(&self) -> f32
pub fn square_magnitude(&self) -> f32
Returns the (non-sqrt) magnitude/length of the vector
pub fn clear(&mut self)
Sourceimpl Vec2d<f64>
impl Vec2d<f64>
Sourcepub fn unit_vector(direction: f64) -> Self
pub fn unit_vector(direction: f64) -> Self
Creates a new unit vector in a specific direction
Sourcepub fn square_magnitude(&self) -> f64
pub fn square_magnitude(&self) -> f64
Returns the (non-sqrt) magnitude/length of the vector
pub fn clear(&mut self)